/*
 *  com.h
 */
#ifndef _COM_H
#define _COM_H

#include <stdio.h>
#include <stdlib.h>
#include <termios.h>
#include <unistd.h>
#include <fcntl.h>
#include <string.h>
#include <sys/types.h>

#include "ad7766.h"
#include "file.h"

/* modes */
#define COM_PISTON 0x01
#define COM_AIRBAG 0x02
#define COM_GPS 0x04
#define COM_DEPTH 0x08
#define COM_TIME 0x10
#define COM_ASCENDING 0x20
#define COM_DESCENDING 0x40
#define COM_PARKED 0x80
#define COM_PROFILING 0x100
#define COM_SURFACE_DETECT 0x200

/* states */
#define COM_EXIT 0
#define COM_RUN 1
#define COM_PAUSE 2
#define COM_RESET 3
#define COM_SLEEP 4

#define COM_BUFSIZE 1024 
#define COM_MSGSIZE 128

struct com_struct {
   int mode;
   int state;
   time_t time; // msg time
   char file[64];  // log file to save messages
   gps_t *gps;
   //click_detect_t *dtx;
   //adc_t *adc;
};

typedef struct com_struct com_t;

//---------------------------------------------------------
/* com message functions */
extern int com_open(char *device, speed_t baud);
extern int com_close();
extern int com_read_msg(char *buf, int n);
extern int com_write_msg(char *buf, int n);
extern int com_write_raw(char *buf, int n);
extern int com_parse_msg(char *buf, int len, com_t *com);
extern int com_send_dtx(int max_ndtx);
extern void *com_handle_msg(void *arg);

#endif /* _COM_H */

