#ifndef _FILE_H
#define _FILE_H
/*
*  file.h: 
*/

/* data record definition */

#define DATA_CLIPPED 0x01
#define DATA_OVERRUN 0x02

typedef long int32;
typedef short int16;
typedef unsigned long uint32;
typedef unsigned short uint16;

struct data_struct {
   struct timeval time;   // start time
   int status;            // data status
   int nsize;             // sample size [bytes]
   int nsamps;            // num of samples per blk [samples]
   int nchans;            // num of channels
   int fs;                // sampling freq [hz]
   int gain;              // pre-amp gain
   int scale;             // data word scaling [shifted bits]
   void *buffer;
};
typedef struct data_struct data_t;

struct header_struct {
   struct timeval time;   // start time
   int nblks;	          /* total number of data buffers in file */
   int nsize;             // sample size [bytes]
   int nsamps;            // num of samples per blk [samples]
   int nchans;            // num of channels
   int fs;                // sampling freq [hz]
   int gain;              // pre-amp gain
   int scale;             // data word scaling [shifted bits]
};
typedef struct header_struct header_t;

struct gps_struct {
   float lat;
   float lon;
   float depth;
   time_t time; // msg time
};
typedef struct gps_struct gps_t;

// file format types
#define DAT_FILE_FORMAT 1
#define WAVE_FILE_FORMAT 2

struct file_struct {
   int format;         // file format type
   char log[32];       // log file name
   char path[32];
   char prefix[8];
   char name[32];      /* current data file name */
   int nbufs;	       /* total number of buffers written */
   int max_nbufs;      /* max number of buffer per file */
   int nbytes;	       /* total number of bytes written */
   unsigned long bsize;	      /* block size (use stat.f_bsize for optimal transfer) */
   unsigned long bfree;	      /* current free blocks in fs */
   unsigned long bfree_min;   /* min free blocks to leave in fs */
   unsigned long blocks;      /* total number of blocks in fs */
   int open_sec;       /* file open time (seconds) */
};

typedef struct file_struct file_t;


/* function prototypes */

extern int file_write(file_t *file, data_t *data);
extern int file_write_hdr(file_t *file, data_t *data);
extern int file_read_hdr(FILE *fp, header_t *hdr);
extern int file_append(file_t *file, data_t *data);
extern int file_append_wave(file_t *file, data_t *data);
extern int file_file_init(file_t *file, char *path, char *prefix, int maxblks);

#endif /* _FILE_H */

