/*
 *  log.c 
 */

#include <stdio.h>
#include <string.h>

FILE *log_fp;
char *log_file;

inline void log_open()
{
   if(log_file[0] != 0) {
      if((log_fp = fopen(log_file, "a+")) == NULL) {
         fprintf(stderr, "Error openning log file\n");
         log_fp = stdout;
      }
   } else log_fp = stdout;
}

inline void log_close()
{
   if(log_file[0] != 0) fclose(log_fp);
}

void log_startup_message(adc_t *adc, apex_file_t *apx, struct statfs *stat)
{
   float duration;
   struct timeval tv;
   char tmstr[32]; // e.g. Tue Dec 21 22:10:50 2010

   log_open();

   // print startup message
   gettimeofday(&tv, NULL);
   ctime_r(&tv.tv_sec, tmstr);
   fprintf(log_fp, "\nStarted at %s", tmstr);
   fprintf(log_fp, "File system: %0.2f MB available",
      ((float)(stat->f_bavail) * (float)(stat->f_bsize) / 1000000.0));
   fprintf(log_fp, ", size %0.2f MB (%ld*%d)\n",
      ((float)(apx->blocks)*(float)(apx->bsize)/1000000.0), apx->blocks, apx->bsize);
   //fprintf(dbg_fp, " %d blocks free.\n", (int)(stat.f_bfree));
   duration = (float)adc->nsamps/(float)adc->fs; // record duration in seconds
   total_duration = ((float)(apx->bfree)*(float)(apx->bsize)/2.0)/(float)adc->fs;
   fprintf(log_fp, "Total duration = %0.2f hours\n", total_duration/(3600.0));
   fprintf(log_fp, "nsamps=%d (%f sec), fs=%d, gain=%d, bitshift=%d, auto_scale=%d\n",
      adc->nsamps, duration, adc->fs, adc->gain, adc->shift, adc->auto_scale);

   log_close();

}

static double curr_time, last_time;

void log_read_message(adc_t *adc, apex_file_t *apx, int ndtx)
{
   // open log file for writing messages
   log_open();

   curr_time = (double)(adc->time.tv_sec) +
               (double)(adc->time.tv_nsec)/1000000000.0;

   //ctime_r(&(adc->time.tv_sec), tmstr);
   //fprintf(log_fp," %d samples read at %s", nrd, tmstr);
   fprintf(log_fp,"buffer=%p, time=%lf, bfree=%d",
               active_buffer, curr_time, apx.bfree);
   if(adc->clipped) fprintf(log_fp,", clipped=%d", adc->clipped);
   if(adc->auto_scale) fprintf(log_fp,", scale=%d", adc->shift);
   if(adc->buffer.overflow) fprintf(log_fp,", overflow");
   if(ndtx) fprintf(log_fp,", ndtx=%d", ndtx);
   fprintf(log_fp,"\n");
   //fprintf(log_fp," write %d bytes, record %d, %d blks free\n",
   //   nwrt, apx.nblks, apx.bfree);

   last_time = curr_time;

   log_close();

}


