/*
*  misc.c: misc blackfin utilities
*
*/

#include <stdio.h>
#include <stdlib.h>
#include <termios.h>
#include <unistd.h>
#include <fcntl.h>
#include <string.h>
#include <signal.h>
#include <errno.h>
#include <sys/types.h>
#include <time.h>
#include <sys/time.h>
#include <math.h>

#include "file.h"

//#define DEBUG

extern int verbose;

/*-------------------------------------------------------------------
 *  message logging functions
 */

void print_log(file_t *file, char *str)
{
   FILE *fp;
   char tmstr[32]; // e.g. Tue Dec 21 22:10:50 2010
   struct timeval tv;
   struct tm time;

   if(file->log[0] != 0) {
      if((fp = fopen(file->log, "a+")) == NULL) {
         fprintf(stderr, "Error openning log file\n");
         fp = stdout;
      }
   } else fp = stdout;

   gettimeofday(&tv, NULL);
   gmtime_r(&tv.tv_sec, &time);
   strftime(tmstr, sizeof(tmstr), "%H:%M:%S %d/%m/%g", &time);
   //ctime_r(&tv.tv_sec, tmstr);
   fprintf(fp, "%s: %s\n", tmstr, str);

   if(file->log[0] != 0) fclose(fp);
}

void print_startup_log(file_t *file, data_t *dat)
{
   float duration, total_duration;
   char str[128];

   print_log(file, "STARTED");

   sprintf(str, "File system: %0.2f MB of %0.2f MB (%0.2f%%) available",
      ((float)(file->bfree)*(float)(file->bsize)/1000000.0),
      ((float)(file->blocks)*(float)(file->bsize)/1000000.0),
      100.0*(float)(file->bfree)/(float)(file->blocks));
   print_log(file, str);

   //fprintf(dbg_fp, " %d blocks free.\n", (int)(stat.f_bfree));
   duration = (float)dat->nsamps/(float)dat->fs; // record duration in seconds
   sprintf(str, "nsamps=%d (%f sec), fs=%d, gain=%d, shift=%d",
      dat->nsamps, duration, dat->fs, dat->gain, dat->scale);
   print_log(file, str);

   total_duration = ((float)(file->bfree)*(float)(file->bsize)/2.0)/(float)dat->fs;
   sprintf(str, "Recording time %0.2f hours", total_duration/(3600.0));
   print_log(file, str);

}

int log_message(char *file, char *msg)
{
   int n;
   FILE *fp;

   // open log file for writing messages
   if(file[0] == 0) {
      fp = stdout;
   } else {
      fp = fopen(file, "w+");
      if(fp == NULL) {
         fprintf(stdout, "Error openning message log file\n");
         return(-1);
      }
   }

   n = fprintf(fp, "%s\n", msg);
   fclose(fp);
   return(n);
}

//---------------------------------------------------------
// system time functions
time_t set_system_time(time_t sec, suseconds_t usec)
{
  struct timeval tv;
  tv.tv_sec = sec;
  tv.tv_usec = usec;
  settimeofday(&tv, NULL);
  return (tv.tv_sec);
}

time_t get_system_time(time_t *sec, suseconds_t *usec)
{
  struct timeval tp;
  gettimeofday(&tp, NULL);
  *usec = tp.tv_usec;
  *sec = tp.tv_sec;
  //fprintf(stdout,"get_system_time: %ld.%06ld\n",tp.tv_sec,tp.tv_usec);
  return(tp.tv_sec);
}

double time_to_double(time_t sec, suseconds_t usec)
{
  double sec_d;
  sec_d = (double)(sec) + (double)(usec)*0.000001;
  return(sec_d);
}

