%
% matlab script to plot wispr data
%

clear all;

[file, dpath, filterindex] = uigetfile('./*.dat', 'Pick a data file');
name = fullfile(dpath,file);

% read header file
hdr_file = [name(1:end-3), 'txt'];
fp = fopen(hdr_file, 'r');
str = fgets(fp);
str = fgets(fp);
str = fgets(fp);  hdr.sec = sscanf(str, 'start time sec: %d');
str = fgets(fp);  hdr.usec = sscanf(str, 'start time usec: %d');
str = fgets(fp);  hdr.fs = sscanf(str, 'samples per second: %d');
str = fgets(fp);  hdr.nblks = sscanf(str, 'blocks per file: %d');
str = fgets(fp);  hdr.nsamps = sscanf(str, 'samples per block: %d');
str = fgets(fp);  hdr.nsize = sscanf(str, 'bytes per sample: %d');
str = fgets(fp);  hdr.nchans = sscanf(str, 'channels: %d');
str = fgets(fp);  hdr.gain = sscanf(str, 'gain: %d');
str = fgets(fp);  hdr.scale = sscanf(str, 'scale: %d');
fclose(fp);

t1=719529;   % this is the date number for Jan 1 1970
[year,month,day,hour,minute,second]  = datevec(t1+(hdr.sec/(24*3600)));
second = second + hdr.usec/1000000;
fprintf('%d/%02d/%02d %02d:%02d:%f\n', year,month,day,hour,minute,second);

fprintf('sec = %d\n', hdr.sec);
fprintf('usec = %d\n', hdr.usec);
fprintf('nblks = %d\n', hdr.nblks);
fprintf('nsamps = %d\n', hdr.nsamps);
fprintf('nchans = %d\n', hdr.nchans);
fprintf('nsize = %d\n', hdr.nsize);
fprintf('fs = %d\n', hdr.fs);
fprintf('gain = %d\n', hdr.gain);
fprintf('scale = %d\n', hdr.scale);

vref = 5.0;  

% open data file 
fmt = 'ieee-le';
fprintf('opening %s\n', file);
fp = fopen(name, 'r', fmt);

nblks = hdr.nblks;

% loop and read data blocks
for n = 1:nblks % block count
    
    if(hdr.nsize == 2)
        data = fread(fp, (hdr.nchans)*(hdr.nsamps), 'int16');
    end
    if(hdr.nsize == 4)
        data = fread(fp, (hdr.nchans)*(hdr.nsamps), 'int32');
    end
    
    if(isempty(data)) break; end
    
    fprintf('Data block %d: ',n);
    
    % data scaling, convert to volts
    if(hdr.nsize == 4)
        q = (vref/2147483392);  % (0111 1111 1111 1111 1111 1111 0000 0000) = 2147483392  
    elseif(hdr.nsize == 2)
        q = vref*(2^(hdr.scale))/(2^23);
    end
    
    sig = q*double(data);

    % time vector
    fs = hdr.fs;
    time = (1:length(sig))/fs; 
    time = time*1e6; % usecs
    
    % plot time series
    figure(1); clf;
    m = 1:256;
    plot(time(m), sig(m), '.');
    axis([time(1) time(256) -vref vref]);
    ylabel('Volts');
    xlabel('Time (usec)');
    str = sprintf('Time Series Vpp = %f Volts',max(sig(m)) - min(sig(m)));
    title(str);
    grid on;

    % Spectrogram
    figure(2); clf;
    nfft = 1024;
    noverlap = 512;
    win = hanning(nfft);
    spectrogram(sig, win, noverlap, nfft, fs, 'yaxis');

    fprintf('Hit Enter to continue.\n');
    pause;

end

fclose(fp);


